==> jc-1.4.0.tar.gz: polyglot/util/typedump/Main.h <==
// public class polyglot.util.typedump.Main

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f9c97fbfb1c5df78 polyglot_util_typedump_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_typedump_Main_H_
#define _JC_polyglot_util_typedump_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_util_typedump_Main$sub_refs	_jc_polyglot_util_typedump_Main$sub_refs;
typedef struct _jc_polyglot_util_typedump_Main$sub_nonrefs	_jc_polyglot_util_typedump_Main$sub_nonrefs;
typedef struct _jc_polyglot_util_typedump_Main$refs	_jc_polyglot_util_typedump_Main$refs;
typedef struct _jc_polyglot_util_typedump_Main$nonrefs	_jc_polyglot_util_typedump_Main$nonrefs;
typedef struct _jc_polyglot_util_typedump_Main$object	_jc_polyglot_util_typedump_Main$object;

typedef const struct _jc_polyglot_util_typedump_Main$vmethods	_jc_polyglot_util_typedump_Main$vmethods;
typedef const struct _jc_polyglot_util_typedump_Main$vtable	_jc_polyglot_util_typedump_Main$vtable;
typedef const struct _jc_polyglot_util_typedump_Main$vtype	_jc_polyglot_util_typedump_Main$vtype;

// Constructors
extern void _jc_polyglot_util_typedump_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_typedump_Main$object *);

// Static methods
extern void _jc_polyglot_util_typedump_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_polyglot_util_typedump_Main$vmethods {
};

// Vtable
struct _jc_polyglot_util_typedump_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_typedump_Main$vmethods	polyglot_util_typedump_Main;
};

// Vtype
struct _jc_polyglot_util_typedump_Main$vtype {
	_jc_type			type;
	_jc_polyglot_util_typedump_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_typedump_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_typedump_Main$refs {
    _jc_polyglot_util_typedump_Main$sub_refs	polyglot_util_typedump_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_typedump_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_typedump_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_typedump_Main$sub_nonrefs	polyglot_util_typedump_Main;
};

// Object instance structure
struct _jc_polyglot_util_typedump_Main$object {
	_jc_polyglot_util_typedump_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_typedump_Main$vtype	*vtype;
	_jc_polyglot_util_typedump_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_typedump_Main$vtype _jc_polyglot_util_typedump_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_typedump_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_typedump_Main$class_object;

#endif	/* _JC_polyglot_util_typedump_Main_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/typedump/Main.h <==
// public class polyglot.util.typedump.Main

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f9c97fbfb1c5df78 polyglot_util_typedump_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_typedump_Main_H_
#define _JC_polyglot_util_typedump_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_util_typedump_Main$sub_refs	_jc_polyglot_util_typedump_Main$sub_refs;
typedef struct _jc_polyglot_util_typedump_Main$sub_nonrefs	_jc_polyglot_util_typedump_Main$sub_nonrefs;
typedef struct _jc_polyglot_util_typedump_Main$refs	_jc_polyglot_util_typedump_Main$refs;
typedef struct _jc_polyglot_util_typedump_Main$nonrefs	_jc_polyglot_util_typedump_Main$nonrefs;
typedef struct _jc_polyglot_util_typedump_Main$object	_jc_polyglot_util_typedump_Main$object;

typedef const struct _jc_polyglot_util_typedump_Main$vmethods	_jc_polyglot_util_typedump_Main$vmethods;
typedef const struct _jc_polyglot_util_typedump_Main$vtable	_jc_polyglot_util_typedump_Main$vtable;
typedef const struct _jc_polyglot_util_typedump_Main$vtype	_jc_polyglot_util_typedump_Main$vtype;

// Constructors
extern void _jc_polyglot_util_typedump_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_typedump_Main$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_polyglot_util_typedump_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_typedump_Main$vmethods {
};

// Vtable
struct _jc_polyglot_util_typedump_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_typedump_Main$vmethods	polyglot_util_typedump_Main;
};

// Vtype
struct _jc_polyglot_util_typedump_Main$vtype {
	_jc_type			type;
	_jc_polyglot_util_typedump_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_typedump_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_typedump_Main$refs {
    _jc_polyglot_util_typedump_Main$sub_refs	polyglot_util_typedump_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_typedump_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_typedump_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_typedump_Main$sub_nonrefs	polyglot_util_typedump_Main;
};

// Object instance structure
struct _jc_polyglot_util_typedump_Main$object {
	_jc_polyglot_util_typedump_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_typedump_Main$vtype	*vtype;
	_jc_polyglot_util_typedump_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_typedump_Main$vtype _jc_polyglot_util_typedump_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_typedump_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_typedump_Main$class_object;

#endif	/* _JC_polyglot_util_typedump_Main_H_ */
